==> haskell-data-bword-0.1.0.2-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-bword
version:              0.1.0.2
visibility:           public
id:                   data-bword-0.1.0.2-IgI0nMiG7Tw33JNJL0agvV
key:                  data-bword-0.1.0.2-IgI0nMiG7Tw33JNJL0agvV
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  a3dbec2a70cedd9c4dadbf329ee28ad8
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-bword-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-bword-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-bword
hs-libraries:         HSdata-bword-0.1.0.2-IgI0nMiG7Tw33JNJL0agvV
depends:              base-4.16.4.0 ghc-prim-0.8.0
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-bword-0.1.0.2-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-bword
version:              0.1.0.2
visibility:           public
id:                   data-bword-0.1.0.2-AcTtELe643OD2aoByNycmZ
key:                  data-bword-0.1.0.2-AcTtELe643OD2aoByNycmZ
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  7889aa5e061cbae73555c1a8a6889d5d
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-bword-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-bword-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-bword-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-bword
hs-libraries:         HSdata-bword-0.1.0.2-AcTtELe643OD2aoByNycmZ
depends:              base-4.17.2.1 ghc-prim-0.9.1
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
